@@ -63,7 +63,7 @@
 #'     scale of the SHAP values.
 #'   - `S_inter`: Numeric array of SHAP interaction values (or `NULL`).
 #' @seealso
-#'   [sv_importance()], [sv_dependence()], [sv_interaction()],
+#'   [sv_importance()], [sv_dependence()], [sv_dependence2D()], [sv_interaction()],
 #'   [sv_waterfall()], [sv_force()], [collapse_shap()]
 #' @examples
 #' S <- matrix(c(1, -1, -1, 1), ncol = 2, dimnames = list(NULL, c("x", "y")))
@@ -110,11 +110,11 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #'   Creates a "shapviz" object from an XGBoost model.
 #' @export
 #' @examples
-#'
+#' \dontrun{
 #' # XGBoost models
-#' X_pred <- data.matrix(iris[, -1L])
-#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = iris[, 1L])
-#' fit <- xgboost::xgb.train(data = dtrain, nrounds = 50L, nthread = 1L)
+#' X_pred <- data.matrix(iris[, -1])
+#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = iris[, 1])
+#' fit <- xgboost::xgb.train(data = dtrain, nrounds = 10, nthread = 1)
 #'
 #' # Will use numeric matrix "X_pred" as feature matrix
 #' x <- shapviz(fit, X_pred = X_pred)
@@ -129,15 +129,13 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #' x <- shapviz(fit, X_pred = dtrain, X = iris)
 #'
 #' # Multiclass setting
-#' params <- list(objective = "multi:softprob", num_class = 3L)
-#' X_pred <- data.matrix(iris[, -5L])
-#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 5L]) - 1L)
-#' fit <- xgboost::xgb.train(
-#'   params = params, data = dtrain, nrounds = 50L, nthread = 1L
-#' )
+#' params <- list(objective = "multi:softprob", num_class = 3, nthread = 1)
+#' X_pred <- data.matrix(iris[, -5])
+#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 5]) - 1)
+#' fit <- xgboost::xgb.train(params = params, data = dtrain, nrounds = 10)
 #'
 #' # Select specific class
-#' x <- shapviz(fit, X_pred = X_pred, which_class = 3L)
+#' x <- shapviz(fit, X_pred = X_pred, which_class = 3)
 #' x
 #'
 #' # Or combine all classes to "mshapviz" object
@@ -145,9 +143,9 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #' x
 #'
 #' # What if we would have one-hot-encoded values and want to explain the original column?
-#' X_pred <- stats::model.matrix(~ . -1, iris[, -1L])
-#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 1L]))
-#' fit <- xgboost::xgb.train(data = dtrain, nrounds = 50L)
+#' X_pred <- stats::model.matrix(~ . -1, iris[, -1])
+#' dtrain <- xgboost::xgb.DMatrix(X_pred, label = as.integer(iris[, 1]))
+#' fit <- xgboost::xgb.train(data = dtrain, nrounds = 10, nthread = 1)
 #' x <- shapviz(
 #'   fit,
 #'   X_pred = X_pred,
@@ -159,29 +157,30 @@ shapviz.matrix = function(object, X, baseline = 0, collapse = NULL,
 #' # Similarly with LightGBM
 #' if (requireNamespace("lightgbm", quietly = TRUE)) {
 #'   fit <- lightgbm::lgb.train(
-#'     params = list(objective = "regression", num_thread = 1L),
-#'     data = lightgbm::lgb.Dataset(X_pred, label = iris[, 1L]),
-#'     nrounds = 50L,
-#'     verbose = -2L
+#'     params = list(objective = "regression", num_thread = 1),
+#'     data = lightgbm::lgb.Dataset(X_pred, label = iris[, 1]),
+#'     nrounds = 10,
+#'     verbose = -2
 #'   )
 #'
 #'   x <- shapviz(fit, X_pred = X_pred)
 #'   x
 #'
 #'   # Multiclass
-#'   params <- list(objective = "multiclass", num_class = 3L, num_thread = 1L)
-#'   X_pred <- data.matrix(iris[, -5L])
-#'   dtrain <- lightgbm::lgb.Dataset(X_pred, label = as.integer(iris[, 5L]) - 1L)
-#'   fit <- lightgbm::lgb.train(params = params, data = dtrain, nrounds = 50L)
+#'   params <- list(objective = "multiclass", num_class = 3, num_thread = 1)
+#'   X_pred <- data.matrix(iris[, -5])
+#'   dtrain <- lightgbm::lgb.Dataset(X_pred, label = as.integer(iris[, 5]) - 1)
+#'   fit <- lightgbm::lgb.train(params = params, data = dtrain, nrounds = 10)
 #'
 #'   # Select specific class
-#'   x <- shapviz(fit, X_pred = X_pred, which_class = 3L)
+#'   x <- shapviz(fit, X_pred = X_pred, which_class = 3)
 #'   x
 #'
 #'   # Or combine all classes to a "mshapviz" object
 #'   mx <- shapviz(fit, X_pred = X_pred)
 #'   mx
-#'   all.equal(mx[[3L]], x)
+#'   all.equal(mx[[3]], x)
+#' }
 #' }
 shapviz.xgb.Booster = function(object, X_pred, X = X_pred, which_class = NULL,
                                collapse = NULL, interactions = FALSE, ...) {
@@ -399,7 +398,9 @@ shapviz.kernelshap <- function(object, X = object[["X"]],
         MoreArgs = list(X = X, collapse = collapse),
         SIMPLIFY = FALSE
       )
-      names(shapviz_list) <- .make_class_names(length(S))
+      if (is.null(names(shapviz_list))) {
+        names(shapviz_list) <- .make_class_names(length(S))
+      }
       return(mshapviz(shapviz_list))
     }
     # Old way: select just one class
